@@ -189,7 +189,7 @@ class Curve:
         assert 0 < delta <= 0.5
         lowestIv = lowestDelta = highestIv = highestDelta = 0
         for idx in range(len(self.markIvs)):
-            print(self.deltas, self.markIvs)
+            # print(self.deltas, self.markIvs)
             if delta < self.deltas[idx]:
                 lowestIv = self.markIvs[idx]
                 lowestDelta = self.deltas[idx]
@@ -223,15 +223,15 @@ class Curve:
                 highestIv = self.markIvs[idx]
                 highestStrike = self.strikes[idx]
 
-        print(
-            highestIv,
-            highestStrike,
-            lowestIv,
-            lowestStrike,
-            self.putCall,
-            should_reverse,
-        )
-        print(self.strikes, self.markIvs)
+        # print(
+        #     highestIv,
+        #     highestStrike,
+        #     lowestIv,
+        #     lowestStrike,
+        #     self.putCall,
+        #     should_reverse,
+        # )
+        # print(self.strikes, self.markIvs)
         if lowestStrike == 0:
             return self.markIvs[idx]
         elif highestStrike == 0:
